==> question2answer-1.2.1-language-it.zip: it/qa-lang-users.php <==
<?php
	
/*
	Question2Answer 1.2.1 (c) 2010, Gideon Greenspan

	http://www.question2answer.org/

	
	File: qa-include/qa-lang-users.php
	Version: 1.2.1
	Date: 2010-07-29 03:54:35 GMT
	Description: Language phrases for user management


	This software is free to use and modify for public websites, so long as a
	link to http://www.question2answer.org/ is displayed on each page. It may
	not be redistributed or resold, nor may any works derived from it.
	
	More about this license: http://www.question2answer.org/license.php


	THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
	INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
	AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
	THE COPYRIGHT HOLDER BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
	SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
	TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
	PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
	LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
	NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
	SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

	return array(
		'about' => 'About:',
		'block_user_button' => 'Blocca l\'utente',
		'blocked_users' => 'Utenti bloccati',
		'change_password' => 'Cambio password',
		'confirm_complete' => 'Grazie - il tuo indirizzo email è stato confermato',
		'confirm_emailed' => 'Un link per la conferma ti è stato inviato via email. Clicca sul link per confermare il tuo indirizzo email.',
		'confirm_title' => 'Conferma dell\'indirizzo email',
		'confirm_wrong_log_in' => 'Codice non corretto - fai il ^1log in^2 per inviare un nuovo link',
		'confirm_wrong_resend' => 'Codice non corretto - clicca qui sotto per inviare un nuovo link',
		'edit_level_button' => 'Modifica il livello dell\'Utente',
		'edit_user_button' => 'Modifica questo Utente',
		'email_confirmed' => 'Confermato',
		'email_exists' => 'Email già associata ad un account',
		'email_handle_label' => 'Email o Username:',
		'email_invalid' => 'Email non valida - controllarla con attenzione',
		'email_label' => 'Email:',
		'email_not_confirmed' => 'Non ancora confermato',
		'email_please_confirm' => 'Prego ^5confermare^6',
		'email_required' => 'Indirizzo email richiesto - non pubblico',
		'forgot_link' => 'Ho dimenticato la mia password',
		'full_name' => 'Nome completo:',
		'handle_empty' => 'Lo Username non deve essere vuoto',
		'handle_exists' => 'Lo Username è stato già preso - provarne un altro',
		'handle_has_bad' => 'Lo Username non deve contenere i seguenti caratteri: ^',
		'handle_label' => 'Username:',
		'last_login_label' => 'Ultimo login:',
		'last_write_label' => 'Ultima azione di scrittura:',
		'level_admin' => 'Amministratore',
		'level_editor' => 'Editore',
		'level_expert' => 'Esperto',
		'level_moderator' => 'Moderatore',
		'level_super' => 'Super-Amministratore',
		'location' => 'Località:',
		'log_in_to_access' => 'Adesso puoi fare ^1log in^2 ed accedere al tuo account.',
		'login_button' => 'Log In',
		'login_limit' => 'Troppe richieste di log in - riprova tra un\'ora',
		'login_title' => 'Log in',
		'member_for' => 'Membro da:',
		'member_type' => 'Tipologia:',
		'new_password_1' => 'Nuova password:',
		'new_password_2' => 'Re-inserisci la nuova password:',
		'no_blocked_users' => 'Nessun utente bloccato trovato',
		'no_permission' => 'Non hai il permesso di effettuare questa operazione',
		'old_password' => 'Vecchia password:',
		'only_shown_admins' => '(visibile solo agli amministratori)',
		'only_shown_moderators' => '(visibile solo ai moderatori)',
		'password_changed' => 'Password cambiata',
		'password_label' => 'Password:',
		'password_min' => 'La Password deve essere di almeno ^ caratteri',
		'password_mismatch' => 'Le nuove password con coincidono',
		'password_sent' => 'La tua nuova Password ti è stata inviata via email',
		'password_wrong' => 'La Password non è corretta',
		'profile_saved' => 'Profilo salvato',
		'register_button' => 'Registrati',
		'register_title' => 'Registrati come nuovo utente',
		'registered_user' => 'Utente registrato',
		'remember_label' => 'Ricordami su questo computer',
		'reset_code_another' => 'inviane un altro',
		'reset_code_emailed' => 'Ti è stata spedita un\'email con il codice per il ripristino',
		'reset_code_label' => 'Codice:',
		'reset_code_wrong' => 'Codice non corretto',
		'reset_title' => 'Ripristina una Password smarrita',
		'save_profile' => 'Salva il Profilo',
		'save_user' => 'Salva l\'Utente',
		'send_confirm_button' => 'Invia un link di conferma',
		'send_password_button' => 'Invia nuova Password',
		'send_reset_button' => 'Invia un email per ripristinare la Password',
		'send_reset_note' => 'Un messaggio con le istruzioni ti sarà inviato al tuo indirizzo email.',
		'special_users' => 'Utenti speciali',
		'unblock_user_button' => 'Sblocca utente',
		'user_blocked' => '(bloccato)',
		'user_not_found' => 'Utente non trovato',
		'view_account_page' => 'Ritorna alla pagina del ^1tuo account^2.',
		'website' => 'Website:',
		'x_ago_from_y' => '^1 fa da ^2',
	);
	

/*
	Omit PHP closing tag to help avoid accidental output
*/

==> question2answer-1.7-language-it.zip: it/qa-lang-users.php <==
<?php
	
/*
	Question2Answer 1.2.1 (c) 2010, Gideon Greenspan

	http://www.question2answer.org/

	
	File: qa-include/qa-lang-users.php
	Version: 1.2.1
	Date: 2010-07-29 03:54:35 GMT
	Description: Language phrases for user management


	This software is free to use and modify for public websites, so long as a
	link to http://www.question2answer.org/ is displayed on each page. It may
	not be redistributed or resold, nor may any works derived from it.
	
	More about this license: http://www.question2answer.org/license.php


	THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
	INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
	AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
	THE COPYRIGHT HOLDER BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
	SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
	TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
	PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
	LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
	NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
	SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

	return array(
		'about' => 'About:',
		'block_user_button' => 'Blocca l\'utente',
		'blocked_users' => 'Utenti bloccati',
		'change_password' => 'Cambio password',
		'confirm_complete' => 'Grazie - il tuo indirizzo email è stato confermato',
		'confirm_emailed' => 'Un link per la conferma ti è stato inviato via email. Clicca sul link per confermare il tuo indirizzo email.',
		'confirm_title' => 'Conferma dell\'indirizzo email',
		'confirm_wrong_log_in' => 'Codice non corretto - fai il ^1log in^2 per inviare un nuovo link',
		'confirm_wrong_resend' => 'Codice non corretto - clicca qui sotto per inviare un nuovo link',
		'edit_user_button' => 'Modifica questo Utente',
		'email_confirmed' => 'Confermato',
		'email_exists' => 'Email già associata ad un account',
		'email_handle_label' => 'Email o Username:',
		'email_invalid' => 'Email non valida - controllarla con attenzione',
		'email_label' => 'Email:',
		'email_not_confirmed' => 'Non ancora confermato',
		'email_please_confirm' => 'Prego ^5confermare^6',
		'email_required' => 'Indirizzo email richiesto - non pubblico',
		'forgot_link' => 'Ho dimenticato la mia password',
		'full_name' => 'Nome completo:',
		'handle_empty' => 'Lo Username non deve essere vuoto',
		'handle_exists' => 'Lo Username è stato già preso - provarne un altro',
		'handle_has_bad' => 'Lo Username non deve contenere i seguenti caratteri: ^',
		'handle_label' => 'Username:',
		'last_login_label' => 'Ultimo login:',
		'last_write_label' => 'Ultima azione di scrittura:',
		'level_admin' => 'Amministratore',
		'level_editor' => 'Editore',
		'level_expert' => 'Esperto',
		'level_moderator' => 'Moderatore',
		'level_super' => 'Super-Amministratore',
		'location' => 'Località:',
		'log_in_to_access' => 'Adesso puoi fare ^1log in^2 ed accedere al tuo account.',
		'login_button' => 'Log In',
		'login_limit' => 'Troppe richieste di log in - riprova tra un\'ora',
		'login_title' => 'Log in',
		'member_for' => 'Membro da:',
		'member_type' => 'Tipologia:',
		'new_password_1' => 'Nuova password:',
		'new_password_2' => 'Re-inserisci la nuova password:',
		'no_blocked_users' => 'Nessun utente bloccato trovato',
		'no_permission' => 'Non hai il permesso di effettuare questa operazione',
		'old_password' => 'Vecchia password:',
		'only_shown_admins' => '(visibile solo agli amministratori)',
		'only_shown_moderators' => '(visibile solo ai moderatori)',
		'password_changed' => 'Password cambiata',
		'password_label' => 'Password:',
		'password_min' => 'La Password deve essere di almeno ^ caratteri',
		'password_mismatch' => 'Le nuove password con coincidono',
		'password_sent' => 'La tua nuova Password ti è stata inviata via email',
		'password_wrong' => 'La Password non è corretta',
		'profile_saved' => 'Profilo salvato',
		'register_button' => 'Registrati',
		'register_title' => 'Registrati come nuovo utente',
		'registered_user' => 'Utente registrato',
		'remember_label' => 'Ricordami su questo computer',
		'reset_code_another' => 'inviane un altro',
		'reset_code_emailed' => 'Ti è stata spedita un\'email con il codice per il ripristino',
		'reset_code_label' => 'Codice:',
		'reset_code_wrong' => 'Codice non corretto',
		'reset_title' => 'Ripristina una Password smarrita',
		'save_profile' => 'Salva il Profilo',
		'save_user' => 'Salva l\'Utente',
		'send_confirm_button' => 'Invia un link di conferma',
		'send_password_button' => 'Invia nuova Password',
		'send_reset_button' => 'Invia un email per ripristinare la Password',
		'send_reset_note' => 'Un messaggio con le istruzioni ti sarà inviato al tuo indirizzo email.',
		'special_users' => 'Utenti speciali',
		'unblock_user_button' => 'Sblocca utente',
		'user_blocked' => '(bloccato)',
		'user_not_found' => 'Utente non trovato',
		'website' => 'Website:',
		'x_ago_from_y' => '^1 fa da ^2',
		'add_user_x_favorites' => "Aggiungi utente ^ ai preferiti",
		'avatar_default' => "Default",
		'avatar_gravatar' => "Visualizza ^1avatar^2",
		'avatar_label' => "Avatar:",
		'avatar_none' => "Nessuno",
		'change_email_link' => " - ^1modifica email^2",
		'confirm_required' => "Per completare la registrazione, clicca sul link di conferma che abbiamo inviato alla tua mail o ^1richiedine un'altra^2.",
		'delete_user_button' => "Elimina utente",
		'hide_all_user_button' => "Nascondi tutti i post di questo utente",
		'mass_mailings_explanation' => "Ricevi le email inviate a tutti gli utenti",
		'mass_mailings' => "Mail generale:",
		'password_none' => "Nessuno. Per loggarti direttamente imposta una password qui sotto.",
		'password_to_set' => "Impostalo nella pagina del tuo profilo",
		'private_messages_explanation' => "Permetti agli utenti di inviarmi mail (senza vedere il mio indirizzo)",
		'private_messages' => "Messaggi privati:",
		'register_limit' => "Troppe registrazione, riprova più tardi.",
		'register_suspended' => "La registrazione di nuovi utenti è stata temporaneamente sospesa. Riprova più tardi.",
		'remove_avatar' => "Rimuovi avatar:",
		'unsubscribe_complete' => "Sei stato rimosso dall'invio di mail massive inviate da ^0. Ti puoi iscrivere nuovamente tramite il tuo ^1account^2.",
		'unsubscribe_title' => "Rimuovi iscrizione",
		'unsubscribe_wrong_log_in' => "Codice non corretto - ^1log in^2 per disattivarti",
		'unsubscribe' => "Rimuovi iscrizione:",
		'approve_required' => "Attendi che il tuo account venga confermato oppure ^1aggiungi altre informazioni^2.",
		'approve_title' => "Utente in attesa di approvazione",
		'approve_user_button' => "Approva utente",
		'approved_user' => "Utente approvato",
		'category_level_add' => " - ^1aggiungi privilegi di categoria^2",
		'category_level_in' => "per le seguenti categorie:",
		'category_level_label' => "Aggiornato al:",
		'category_level_none' => "Nessun aggiornamento",
		'level_for_category' => "^1 per ^2",
		'level_in_general' => "in generale",
		'only_shown_editors' => "(visibile dagli editors in su)",
		'only_shown_experts' => "(visibile dagli experts in su)",
		'wall_posts' => "Messaggi in bacheca:",
		'wall_posts_explanation' => "Permetti agli utenti di scrivere sulla tua bacheca (ti verrà notificato tramite mail)",
		'registered_label' => "Registrati:",
		'remember' => "Ricorda",
		'edit_profile' => 'Modifica il mio profilo',
		'terms_not_accepted' => 'Devi selezionare questo.',
	);
	

/*
	Omit PHP closing tag to help avoid accidental output
*/
